@@ -1,6 +1,6 @@
 from dataclasses import dataclass, field
 
-from omegaconf import MISSING, DictConfig, ListConfig
+from omegaconf import MISSING, SI, DictConfig, ListConfig
 
 from .commandline import cli
 from .core import (
@@ -26,8 +26,10 @@ from .core import (
 from .flexyclasses import flexyclass
 from .initialize import Target, init
 from .logging import configure_logging
+from .memoizer import memoize
 from .resolvers import all_resolvers, register
 from .shortcuts import (
+    debug_logger,
     fdict,
     flist,
     get_nickname,
@@ -48,6 +50,7 @@ __all__ = [
     "cli",
     "configure_logging",
     "dataclass",
+    "debug_logger",
     "DEFAULT",
     "DictConfig",
     "edit_list",
@@ -68,11 +71,13 @@ __all__ = [
     "ListConfig",
     "make_flexy",
     "make_target",
+    "memoize",
     "merge",
     "MISSING",
     "nickname",
     "register",
     "resolve",
+    "SI",
     "Target",
     "to_dict",
     "to_json",
