@@ -1,3 +1,4 @@
+import re
 import sys
 from argparse import Action
 from dataclasses import dataclass, fields, is_dataclass
@@ -14,9 +15,12 @@ from typing import (
     Union,
 )
 
-from omegaconf import MISSING, DictConfig
+from omegaconf import MISSING, DictConfig, ListConfig
+from omegaconf.errors import ConfigKeyError, ValidationError
 from typing_extensions import Concatenate, ParamSpec
 
+from springs.logging import configure_logging
+
 from .core import (
     from_dataclass,
     from_file,
@@ -51,6 +55,7 @@ class Flag:
     nargs: Optional[Union[str, int]] = MISSING
     metavar: Optional[str] = MISSING
     usage_extras: Optional[str] = MISSING
+    choices: Optional[Sequence[Any]] = MISSING
 
     @property
     def short(self) -> str:
@@ -108,9 +113,18 @@ class CliFlags:
         help="Print the parsed configuration.",
         action="store_true",
     )
+    log_level: Flag = Flag(
+        name="log-level",
+        help=(
+            "Logging level to use for this program. Can be one of "
+            "CRITICAL, ERROR, WARNING, INFO, or DEBUG. Defaults to WARNING."
+        ),
+        default="WARNING",
+        choices=["CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG"],
+    )
     debug: Flag = Flag(
         name="debug",
-        help="Enter debug mode by setting global logging to DEBUG.",
+        help="Enable debug mode; equivalent to --log-level DEBUG.",
         action="store_true",
     )
     quiet: Flag = Flag(
@@ -128,7 +142,7 @@ class CliFlags:
     )
     nicknames: Flag = Flag(
         name="nicknames",
-        help="Print all registered nicknames in Springs",
+        help="Print all registered nicknames in Springs.",
         action="store_true",
     )
 
@@ -142,21 +156,14 @@ class CliFlags:
     def add_argparse(self, parser: RichArgumentParser) -> Sequence[Action]:
         return [flag.add_argparse(parser) for flag in self.flags]
 
-    @property
-    def usage(self) -> str:
-        """Print the usage string for the CLI flags."""
-        return " ".join(flag.usage for flag in self.flags)
-
     def make_cli(self, func: Callable, name: str) -> RichArgumentParser:
         """Sets up argument parser ahead of running the CLI. This includes
         creating a help message, and adding a series of flags."""
         # Program name and usage added here.
         ap = RichArgumentParser(
             description=f"Parser for configuration {name}",
-            usage=(
-                f"python3 {sys.argv[0]} {self.usage} "
-                "param1=value1 … paramN=valueN"
-            ),
+            entrypoint=sys.argv[0],
+            arguments="param1=value1 … paramN=valueN",
         )
         self.add_argparse(ap)
         return ap
@@ -192,11 +199,43 @@ def check_if_valid_main_args(func: Callable, args: Sequence[Any]):
         raise RuntimeError(msg)
 
 
+C = TypeVar("C", DictConfig, ListConfig)
+
+
+def merge_and_catch(c1: C, c2: Union[DictConfig, ListConfig]) -> C:
+    """Improves printing of errors when merging configs in cli."""
+    try:
+        return merge(c1, c2)
+    except Exception as e:
+        prefix = "Error when merging cli options and files with struct config:"
+
+        if isinstance(e, ConfigKeyError):
+            msg, *_ = e.args[0].split("\n")
+        elif isinstance(e, ValidationError):
+            msg, key, *_ = e.args[0].split("\n")
+            _, key = key.split("full_key: ", 1)
+            msg = f"{msg} for key '{key}'"
+        else:
+            msg = str(e.args)
+
+        raise type(e)(f"{prefix} {msg}!")
+
+
+def validate_leftover_args(args: Sequence[str]):
+    var_pattern = r"[a-zA-Z_]+[a-zA-Z0-9_]*"
+    re_valid = re.compile(rf"({var_pattern}\.?)*{var_pattern}=.+")
+    for arg in args:
+        if not re_valid.match(arg):
+            raise ValueError(
+                f"'{arg}' is not an option and it does not match the pattern "
+                "'path.to.key=value' expected for a cli config override."
+            )
+
+
 def wrap_main_method(
     func: Callable[Concatenate[Any, MP], RT],
     name: str,
     config_node: DictConfig,
-    print_fn: Optional[Callable] = None,
     *args: MP.args,
     **kwargs: MP.kwargs,
 ) -> RT:
@@ -212,12 +251,12 @@ def wrap_main_method(
     ap = CliFlags().make_cli(func=func, name=name)
     opts, leftover_args = ap.parse_known_args()
 
-    # setup debug
-    if opts.debug:
-        # relative import here not to mess things up
-        from .logging import configure_logging
+    # Checks if the args are a match for the 'path.to.key=value′ pattern
+    # expected for configuration overrides.
+    validate_leftover_args(leftover_args)
 
-        configure_logging.debug()
+    # setup logging level for the root logger
+    configure_logging(logging_level="DEBUG" if opts.debug else opts.log_level)
 
     # We don't run the main program if the user
     # has requested to print the any of the config.
@@ -238,10 +277,10 @@ def wrap_main_method(
             columns=["Resolver Name"],
             values=[(r,) for r in sorted(all_resolvers())],
             caption=(
-                "Resolvers use syntax ${resolver_name:'arg1','arg2'}. "
+                "Resolvers use syntax ${resolver_name:'arg1','arg2'}.\n"
                 "For more information, visit https://omegaconf.readthedocs.io/"
                 "en/latest/custom_resolvers.html"
-            )
+            ),
         )
 
     if opts.nicknames:
@@ -255,8 +294,7 @@ def wrap_main_method(
                 "Nicknames are invoked via: "
                 "${sp.from_node:nickname,'path.to.key1=value1',...}. "
                 "\nOverride keys are optional (but quotes are required)."
-
-            )
+            ),
         )
 
     # Print default options if requested py the user
@@ -276,8 +314,9 @@ def wrap_main_method(
         # print the configuration if requested by the user
         if opts.inputs:
             print_config_as_tree(
-                title=f"[blue]Input From File {config_file}[/blue]",
+                title=f"Input From File {config_file}",
                 config=file_config,
+                title_color="blue",
             )
 
         # merge the file config with the main config
@@ -289,7 +328,9 @@ def wrap_main_method(
     # print the configuration if requested by the user
     if opts.inputs:
         print_config_as_tree(
-            title="[red]Input From Command Line[/red]", config=cli_config
+            title="Input From Command Line",
+            config=cli_config,
+            title_color="red",
         )
 
     # merge the cli config with the main config, do it last
@@ -304,12 +345,14 @@ def wrap_main_method(
     # finally merge the accumulator config with the main config
     # using the safe merging function, which will resolve interpolations
     # and perform type checking.
-    parsed_config = merge(config_node, accumulator_config)
+    parsed_config = merge_and_catch(config_node, accumulator_config)
 
     # print it if requested
     if not (opts.quiet) or opts.parsed:
         print_config_as_tree(
-            title="[green]Parsed Config[/green]", config=parsed_config
+            title="Parsed Config",
+            config=parsed_config,
+            title_color="green",
         )
 
     if do_no_run:
@@ -323,7 +366,6 @@ def wrap_main_method(
 
 def cli(
     config_node_cls: Optional[Type[CT]] = None,
-    print_fn: Optional[Callable] = None,
 ) -> Callable[
     [
         # this is a main method that takes as first input a parsed config
@@ -362,8 +404,6 @@ def cli(
     Args:
         config_node_cls (Optional[type]): The class of the configuration
             node. If not provided, no type checking will be performed.
-        print_fn (Optional[Callable]): A function to use for printing.
-            If not provided, `print` will be used.
 
     Returns:
         Callable: A decorator that can be used to decorate a method.
@@ -392,7 +432,6 @@ def cli(
                 func,
                 name,
                 config_node,
-                print_fn,
                 *args,
                 **kwargs,
             )
